<?php 
/*
	Plugin Name: WooCommerce Boleto Banco do Brasil
	Plugin URI: http://www.vibemidia.com//woocommerce-boleto-banco-do-brasil
	Description: Plugin para integrar boleto bancário Banco do Brasil como meio de pagamento. Siga as <a href="http://www.vibemidia.com/woocommerce-boleto-banco-do-brasil" title="instruções de uso" target="_blank">instruções de uso</a>.
	Version: 1.2
	Author: John-Henrique 
	Author URI: http://vibemidia.com
	Requires at least: 3.3.2
	Tested up to: 3.4
	Text domain: boletoBB
*/

/*  Copyright 2012 John-Henrique 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/



add_action('plugins_loaded', 'init_woocommerce_boletoBB', 0);

function init_woocommerce_boletoBB(){
	
	
	if ( !class_exists( 'WC_Payment_Gateway' ) ) { return; }
	
	
	
	class BoletoBBGateway extends WC_Payment_Gateway {
		
		
		public function __construct(){
			global $woocommerce;
			
	        $this->id = 'BoletoBB';
			$this->method_title = 'Boleto Banco do Brasil';
			$this->icon = apply_filters('woocommerce_boletoBB_icon', WP_PLUGIN_URL . "/" . plugin_basename( dirname(__FILE__)) . '/imagens/boleto.png' );
			$this->has_fields = false;
			
			// Load the form fields.
			$this->init_form_fields();
			
			// Load the settings.
			$this->init_settings();
			
			// Define user set variables
			$this->title = $this->settings['title'];
			$this->description = $this->settings['description'];
			$this->instrucoes = $this->settings['instrucoes'];
			
			
			/**
			 * Dados da empresa cedente
			 */
			$this->identificacao = $this->settings['identificacao'];
			$this->cpf_cnpj = $this->settings['cpf_cnpj'];
			$this->endereco = $this->settings['endereco'];
			$this->cidade_uf = $this->settings['cidade_uf'];
			$this->cedente = $this->settings['cedente'];
			
			
			/**
			 * Dados da conta
			 */
			$this->agencia = $this->settings['agencia'];
			$this->conta = $this->settings['conta'];
			$this->convenio = $this->settings['convenio'];
			$this->numero_documento = $this->settings['numero_documento'];
			$this->contrato = $this->settings['contrato'];
			$this->carteira = $this->settings['carteira'];
			$this->variacao_carteira = $this->settings['variacao_carteira'];
			$this->taxa = $this->settings['taxa'];
			
			/**
			 * Tipo de boleto
			 */
			$this->formatacao_convenio = $this->convenio();
			$this->formatacao_convenio = $this->settings['formatacao_convenio'];
			$this->formatacao_nosso_numero = $this->nosso_numero();
			
			/**
			 * Opcionais de acordo com o banco
			 */
			$this->quantidade = $this->settings['quantidade'];
			$this->valor_unitario = $this->settings['valor_unitario'];
			$this->aceite = $this->settings['aceite'];
			$this->especie = $this->settings['especie'];
			$this->especie_doc = $this->settings['especie_doc'];
			
			/**
			 * Informações para o comprador
			 */
			$this->demonstrativo1 = __( "Pagamento do pedido N ", 'boletoBB' );
			$this->demonstrativo2 = sprintf( __( "Taxa de emissão do boleto: R$ %s", 'boletoBB' ), number_format( $this->taxa, 2, ',', '' ) );
			$this->demonstrativo3 = get_bloginfo( 'name' ) .' - '. get_bloginfo( 'url' );

			/**
			 * Instruções para o caixa
			 */
			$this->vencimento = $this->settings['vencimento'];
			$this->instrucoes1 = ( !$this->settings['juros'] )?'': sprintf( __( "Sr. Caixa, cobrar multa de R$ %s%  \após o vencimento", 'boletoBB' ), $this->settings['juros'], '% ' );
			$this->instrucoes2 = ( !$this->settings['vencimento'] )?'': sprintf( __( "Após o vencimento receber até %s", 'boletoBB' ), $this->vencimento() );
			$this->instrucoes3 = ( !$this->settings['contato'] )?'': sprintf( __( "Em caso de dúvidas entre em contato com %s", 'boletoBB' ), $this->settings['contato'] );
			$this->instrucoes4 = __( "Boleto emitido por ", 'boletoBB' ) . $this->demonstrativo3;
			
			
			
			
			$this->logo = apply_filters('woocommerce_boletoBB_logo', WP_PLUGIN_URL . "/" . plugin_basename( dirname(__FILE__)) . '/imagens/logo_empresa.png' );
			
			
            
			$this->debug = $this->settings['debug'];	
			// Logs
			if ($this->debug=='yes') $this->log = $woocommerce->logger();
			
			
			// Actions
			add_action('woocommerce_update_options_payment_gateways', array(&$this, 'process_admin_options'));
			add_action('woocommerce_thankyou_BoletoBB', array(&$this, 'thankyou_page'));
			add_action('woocommerce_receipt_BoletoBB',	array(&$this, 'receipt_page' ));
			
			// Customer Emails
			//add_action('woocommerce_email_before_order_table', array(&$this, 'email_instructions'), 10, 2);
			
			
			// [imprimir_boleto_*]
			add_shortcode( print_page_bb(), array( &$this, 'gera_boleto' ) );
		}
			
	
		
		public function init_form_fields(){
			
			$this->form_fields = array(
				'enabled' => array(
					'title' => __( 'Habilitar/desabilitar', 'boletoBB' ),
					'type' => 'checkbox',
					'label' => __( 'Habilitar Boleto Banco do Brasil', 'boletoBB' ),
					'default' => 'yes'
				),
				'title' => array(
					'title' => __( 'Rótulo', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Isto controla o que o comprador vai ver na tela de pagamento.', 'boletoBB' ),
					'default' => __( 'Boleto Banco do Brasil', 'boletoBB' )
				),
				'description' => array(
					'title' => __( 'Descrição deste método de pagamento', 'boletoBB' ),
					'type' => 'textarea',
					'description' => __( 'Isto controla a descrição do serviço de cobrança na tela de opções de pagamento.', 'boletoBB' ),
					'default' => 'Pagar através de boleto bancário Banco do Brasil.'
				),
				'instrucoes' => array(
					'title' => __( 'Instruções sobre o pagamento', 'boletoBB' ),
					'type' => 'textarea',
					'description' => __( 'Esta informação será enviada no email de confirmação da compra. Adicione [boleto] no local onde deseja exibir o link para impressão do boleto. Exemplo: Imprima seu boleto clicando neste link [boleto].', 'boletoBB' ), 
					'default' => 'Clique neste link [boleto] para imprimir o boleto, você pode pagar este boleto em qualquer agência bancária até a data do vencimento, após o vencimento pagável apenas nas agências do Banco do Brasil.'
				),
				
				
				/**
				 * Dados da empresa cedente
				 */
				'logo' => array(
					'title' => __( 'Logo da sua loja', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o URL de uma imagem no tamanho máximo de 147px por 46px. Utilize a <a href="media-upload.php?type=image&TB_iframe=1&width=640&height=672" target="_blank" title="Media library" class="thickbox">Biblioteca de mídia</a>', 'boletoBB' ),
					'default' => __( '', 'boletoBB' )
				),
				'identificacao' => array(
					'title' => __( 'Identificação', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o nome da sua empresa.', 'boletoBB' ),
					'default' => __( '', 'boletoBB' )
				),
				'cpf_cnpj' => array(
					'title' => __( 'CNPJ', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o CNPJ da sua empresa.', 'boletoBB' ),
					'default' => __( '', 'boletoBB' )
				),
				'endereco' => array(
					'title' => __( 'Endereço', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o endereço da empresa.', 'boletoBB' ),
					'default' => __( '', 'boletoBB' )
				),
				'cidade_uf' => array(
					'title' => __( 'Cidade e UF', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe a cidade e UF, no formato "Cidade-UF".', 'boletoBB' ),
					'default' => __( '', 'boletoBB' )
				),
				'cedente' => array(
					'title' => __( 'Cedente', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe a razão social da sua empresa', 'boletoBB' ),
					'default' => __( '', 'boletoBB' )
				), 
				
				
				/**
				 * Dados bancários da empresa cedente
				 */
				'agencia' => array(
					'title' => __( 'Código da agência', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o código da agência bancária conveniada', 'boletoBB' ),
					'default' => __( '00000', 'boletoBB' )
				), 
				'conta' => array(
					'title' => __( 'Número da conta', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o número da conta conveniada', 'boletoBB' ),
					'default' => __( '00000', 'boletoBB' )
				), 
				'convenio' => array(
					'title' => __( 'Código do convenio', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o código do convenio bancário', 'boletoBB' ),
					'default' => __( '00000', 'boletoBB' )
				), 
				'contrato' => array(
					'title' => __( 'Número do contrário', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o número do contrato', 'boletoBB' ),
					'default' => __( '00000', 'boletoBB' )
				), 
				'numero_documento' => array(
					'title' => __( 'Número do documento', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o número do documento', 'boletoBB' ),
					'default' => __( '00000', 'boletoBB' )
				), 
				'carteira' => array(
					'title' => __( 'Tipo de carteira', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe o tipo de carteira, normalmente não é necessário alterar', 'boletoBB' ),
					'default' => __( '18', 'boletoBB' )
				), 
				'variacao_carteira' => array(
					'title' => __( 'Variação da carteira', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe a variação da carteira', 'boletoBB' ),
					'default' => __( '-19', 'boletoBB' )
				),
				'formatacao_convenio' => array(
					'title' => __( 'Formato convenio', 'boletoBB' ),
					'type' => 'select',
					'description' => __( 'Selecione o formato do convenio', 'boletoBB' ),
					'options' => array(
									8 => '8 digitos', 
									7 => '7 digitos', 
									6 => '6 digitos', 
								), 
					'default' => __( 7, 'boletoBB' )
				),  
				
				/**
				 * @deprecated agora utilizamos as funções
				 * convenio()
				 * nosso_numero()
				 */
				/*
				'formatacao_nosso_numero' => array(
					'title' => __( 'Formato nosso número', 'boletoBB' ),
					'type' => 'select',
					'description' => __( 'Selecione o formato do convenio', 'boletoBB' ),
					'options' => array(
									2 => 'MAIS de 6 digitos', 
									1 => 'MENOS de 6 digitos'
								), 
					'default' => __( 'Informe a razão social da sua empresa', 'boletoBB' )
				),
				*/
				
				/**
				 * Instruções para o caixa
				 */
				'vencimento' => array(
					'title' => __( 'Vencimento do boleto', 'boletoBB' ), 
					'description' => sprintf(__( 'Após a emissão os boletos devem vencer em quantos dias? Veja %svencimento de boletos%s para mais informações', 'boletoBB' ), '<a href="http://vibemidia.com/woocommerce-boleto-banco-do-brasil" target="_blank">','</a>'), 
					'type' => 'select', 
					'options' => array(
								'1' => '1 dia',
								'2' => '2 dias',
								'3' => '3 dias',
								'5' => '5 dias',
								'5' => '5 dias',
								'10' => '10 dias',
								'15' => '15 dias',
								'20' => '20 dias',
								'25' => '25 dias',
								'30' => '30 dias',
								),
					'default' => '3'
				), 
				'juros' => array(
					'title' => __( 'Juros por atraso', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Quanto cobrar de juros após o vencimento (apenas números, exemplo 2 para 2%)', 'boletoBB' ),
					'default' => __( '0', 'boletoBB' )
				), 
				'taxa' => array(
					'title' => __( 'Taxa de emissão', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Qual o valor cobrado pela emissão do boleto bancário? (apenas números, exemplo 2.95 para R$ 2,95)', 'boletoBB' ),
					'default' => __( '0', 'boletoBB' )
				), 
				'contato' => array(
					'title' => __( 'Informações de contato', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Informe um email ou telefone para contactar em caso de dúvidas', 'boletoBB' ),
					'default' => __( '0', 'boletoBB' )
				), 
				
				
				/**
				 * Dados opcionais
				 */
				'quantidade' => array(
					'title' => __( 'Quantidade', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Opcional de acordo com o banco', 'boletoBB' ),
					'default' => __( '10', 'boletoBB' )
				), 
				'valor_unitario' => array(
					'title' => __( 'Valor unitário', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Opcional de acordo com o banco', 'boletoBB' ),
					'default' => __( '10', 'boletoBB' )
				), 
				'aceite' => array(
					'title' => __( 'Aceite', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Opcional de acordo com o banco', 'boletoBB' ),
					'default' => __( 'N', 'boletoBB' )
				), 
				'especie' => array(
					'title' => __( 'Espécie', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Opcional de acordo com o banco', 'boletoBB' ),
					'default' => __( 'R$', 'boletoBB' )
				), 
				'especie_doc' => array(
					'title' => __( 'Espécie de documento', 'boletoBB' ),
					'type' => 'text',
					'description' => __( 'Opcional de acordo com o banco', 'boletoBB' ),
					'default' => __( 'DM', 'boletoBB' )
				), 
				'debug' => array(
					'title' => __( 'Enable/Disable Log', 'boletoBB' ), 
					'type' => 'checkbox', 
					'description' => __( 'Enable logging (<code>woocommerce/logs/BoletoBB.txt</code>)', 'boletoBB' ), 
					'default' => ''
				),
				
			);
			
		}
		
		
		public function admin_options(){
			
			wp_enqueue_script( 'thickbox' );
			
			?>
		    <h3><?php _e('Boleto Banco do Brasil', 'boletoBB'); ?></h3>
			<p><?php _e('Preencha os campos abaixo com as informações fornecidas pelo gerente do seu banco, normalmente estes dados estão disponíveis no contrato de serviço.', 'boletoBB'); ?></p>
			<table class="form-table">
			<?php
				// Generate the HTML For the settings form.
				$this->generate_settings_html();
			?>
			</table>
			<?php
		} // End admin_options()
		
		
		
		public function payment_fields() {
			if ($this->description) echo wpautop(wptexturize($this->description));
		}
		
		
		
		/**
		 * Informa o final do processo de pagamento
		 *
		 */
		public function thankyou_page() {
			global $woocommerce;
			
			// Evita probleminhas
			if( !isset( $_GET['order'] ) ){ return; }
			
			
			$urlBoleto = wp_nonce_url( add_query_arg( 'order', (int) $_GET['order'], get_permalink( get_page_by_path( print_page_bb() ) ) ), 'boletoBB' );
			
			
			$woocommerce->add_inline_js( 'window.open("'. str_replace( 'amp;', '', $urlBoleto ) .'", "_blank");');
			?>
		    <h3><?php _e('Imprima o boleto bancário', 'boletoBB'); ?></h3>
			<p><?php echo sprintf( __('Caso você não seja direcionado a tela do boleto, %s<strong>clique aqui para exibir o boleto</strong></a>.', 'boletoBB'), '<a href="'. $urlBoleto .'" target="_blank">' ); ?></p>
			<?php
		}
		
			
		
		
		public function process_payment( $order_id ) {
			global $woocommerce;
			
			$order = &new WC_Order( $order_id );
			
			$order->update_status('on-hold', __('Aguardando confirmação de pagamento do boleto', 'boletoBB'));
			$order->add_order_note( __('Aguardando confirmação de pagamento do boleto', 'boletoBB') );
			
			
			// Remove cart
			$woocommerce->cart->empty_cart();
			
			// Empty awaiting payment session
			unset($_SESSION['order_awaiting_payment']);
			
			// Return thankyou redirect
			return array(
				'result'	=> 'success',
				'redirect'	=> add_query_arg('key', $order->order_key, add_query_arg('order', $order_id, get_permalink(get_option('woocommerce_thanks_page_id'))))
			);
		}
		
		
		
		
		public function receipt_page( $order ){
			echo '<p>'.__('Obrigado por realizar sua compra. Clique no botão abaixo para realizar seu pagamento.', 'boletoBB').'</p>';
		}
		
		

		/**
		 * Retorna uma mensagem personalizada 
		 * sobre o método de pagamento
		 * 
		 * Este é um item que permite enviar o 
		 * link do boleto ao email do comprador
		 *
		 */
		public function email_instructions(){
			echo str_replace( '[boleto]', $this->url_boleto, $this->instrucoes );
		}
		
		
		
		/**
		 * Formata e corrige valores para somar o valor cobrado 
		 * com a taxa de emissão
		 *
		 * @param Integer $valor_cobrado
		 * @return Integer
		 */
		protected function valor( $valor_cobrado = 0 ){
			return number_format( str_replace( ',', '.', $valor_cobrado ) + str_replace( ',', '.', $this->taxa ), 2, ',', '' );
		}
		
		
		
		/**
		 * Retorna o formato do convenio
		 *
		 * @return Integer
		 */
		protected function convenio(){
			return count( $this->convenio );
		}
		
		
		/**
		 * Retorna o formato do nosso numero
		 *
		 * @return Integer
		 */
		protected function nosso_numero(){
			
			// convenio com 6 digitos?
			if( count( $this->convenio ) == 6 ){
				
				// aplicando a regra no nosso numero
				return ( count( $this->nosso_numero ) >= 5 )?1:2;
			}
		}
		
		
		/**
		 * Retorna a data de vencimento do boleto
		 *
		 * @return String data
		 */
		protected function vencimento(){
			return date("d/m/Y", time() + ( $this->vencimento * 86400));
		}
		
		
		/**
		 * Gera o boleto bancário
		 *
		 */
		public function gera_boleto( ){
			
			
			
			$order = &new WC_Order( $_GET['order'] );
			
			// atalho
			$dia = date("d/m/Y");
			
			// DADOS DO BOLETO
			$dadosboleto["nosso_numero"] = $order->id;
			$dadosboleto["numero_documento"] = $this->numero_documento;
			$dadosboleto["data_vencimento"] = $this->vencimento();
			$dadosboleto["data_documento"] = $dia;
			$dadosboleto["data_processamento"] = $dia; // opcional
			$dadosboleto["valor_boleto"] = $this->valor( $order->order_total );
			
			// DADOS DO SEU CLIENTE
			$dadosboleto["sacado"] = $order->billing_first_name ." ". $order->billing_last_name;
			$dadosboleto["endereco1"] = $order->billing_address_1 .' - '. $order->billing_address_2;
			$dadosboleto["endereco2"] = $order->billing_city .'-'. $order->billing_state .' - '. $order->billing_postcode;
			
			// INFORMACOES PARA O CLIENTE
			$dadosboleto["demonstrativo1"] = $this->demonstrativo1 . $order->id;
			$dadosboleto["demonstrativo2"] = $this->demonstrativo2;
			$dadosboleto["demonstrativo3"] = $this->demonstrativo3;
			
			// INSTRU��ES PARA O CAIXA
			$dadosboleto["instrucoes1"] = $this->instrucoes1;
			$dadosboleto["instrucoes2"] = $this->instrucoes2;
			$dadosboleto["instrucoes3"] = $this->instrucoes3;
			$dadosboleto["instrucoes4"] = $this->instrucoes4;
			
			// DADOS OPCIONAIS DE ACORDO COM O BANCO OU CLIENTE
			$dadosboleto["quantidade"] = $this->quantidade;
			$dadosboleto["valor_unitario"] = $this->valor_unitario;
			$dadosboleto["aceite"] = $this->aceite;
			$dadosboleto["especie"] = $this->especie;
			$dadosboleto["especie_doc"] = $this->especie_doc;
			
			
			// ---------------------- DADOS FIXOS DE CONFIGURACAO DO BOLETO --------------- //
			// DADOS DA SUA CONTA - BANCO DO BRASIL
			$dadosboleto["agencia"] = $this->agencia; // Num da agencia, sem digito
			$dadosboleto["conta"] = $this->conta;// Num da conta, sem digito
			
			// DADOS PERSONALIZADOS - BANCO DO BRASIL
			$dadosboleto["convenio"] = $this->convenio;
			$dadosboleto["contrato"] = $this->contrato;
			$dadosboleto["carteira"] = $this->carteira;
			$dadosboleto["variacao_carteira"] = $this->variacao_carteira;
			
			// TIPO DO BOLETO
			$dadosboleto["formatacao_convenio"] = $this->convenio();
			$dadosboleto["formatacao_convenio"] = 7;
			$dadosboleto["formatacao_nosso_numero"] = $this->nosso_numero();
			
			// SEUS DADOS
			$dadosboleto["identificacao"] = $this->identificacao;
			$dadosboleto["cpf_cnpj"] = $this->cpf_cnpj;
			$dadosboleto["endereco"] = $this->endereco;
			$dadosboleto["cidade_uf"] = $this->cidade_uf;
			$dadosboleto["cedente"] = $this->cedente;

			
			

			include("include/funcoes_bb.php"); 
			include("include/layout_bb.php");
			
		}
	}
}

function add_boletoBB_gateway( $methods ){
	$methods[] = 'BoletoBBGateway'; return $methods;
}
add_filter('woocommerce_payment_gateways', 'add_boletoBB_gateway' );




function print_page_bb(){
	return "imprimir_boleto_banco_do_brasil";
}

/**
 * Adiciona a página de impressão
 *
 */
function install_page_bb( $print_page ){
	global $wpdb;
	
	$print_page = print_page_bb();
	
	
	/**
	 * Para evitar páginas duplicadas
	 * Verificamos se existe a página imprimir_boleto
	 */
	$page_found = $wpdb->get_var("SELECT ID FROM " . $wpdb->posts . " WHERE post_name = '". $print_page ."' LIMIT 1;");
	
	if( !$page_found ):
		
		/**
		 * É possível que algum blog tenha uma página 
		 * com slug 'imprimir-boleto', então, para 
		 * evitar problemas nossa página será 
		 * 'imprimir_boleto', fugindo do padrão 
		 * fornecido pelo WordPress.
		 */
		$page_data = array(
	        'post_status' 		=> 'publish',
	        'post_type' 		=> 'page',
	        'post_author' 		=> 1,
	        'post_name' 		=> $print_page, // **
	        'post_title' 		=> ucwords( str_replace( '_', ' ', $print_page ) ),
	        'post_content' 		=> '['. $print_page .']',
	        'post_parent' 		=> '',
	        'comment_status' 	=> 'closed'
	    );
	    
	    // cria a página
	    $post_id = wp_insert_post( $page_data );
	    
	    update_post_meta( $post_id, '_wp_page_template', $print_page .'.php' );
	    
    endif;
}


/**
 * Copia o template de impressao dos boletos
 * 
 * É necessário verificar se:
 * 	O arquivo existe
 * 	O diretório permite escrita
 * 	Se já existe um template lá
 *
 */
function copy_template_page(){
	
	$print_page = print_page_bb();
	
	
	// Diretório do template atual
	$template_dir = get_theme_root() .'/'. get_option( 'template' );
	
	// Arquivo page template imprime_boleto.php
	$plugin_dir = plugin_dir_path( __FILE__ ) . $print_page .".php";
	
	
	// verificando se o arquivo existe
	if( file_exists( $plugin_dir ) && is_writable( $template_dir ) && !file_exists( $template_dir .'/'. $print_page .'.php' ) ){
		
		if( copy( $plugin_dir, $template_dir .'/'. $print_page .'.php' ) ){
			return true;
		}
	}
}
			
// chamada para a instalação
register_activation_hook( __FILE__, 'install_page_bb' );
register_activation_hook( __FILE__, 'copy_template_page_bb' );

?>